@@ -17,7 +17,6 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/armon/go-socks5"
 	"github.com/haxii/fastproxy/bufiopool"
 	"github.com/haxii/fastproxy/superproxy"
 	"github.com/projectdiscovery/dsl"
@@ -35,7 +34,9 @@ import (
 	"github.com/projectdiscovery/tinydns"
 	errorutil "github.com/projectdiscovery/utils/errors"
 	readerUtil "github.com/projectdiscovery/utils/reader"
+	sliceutil "github.com/projectdiscovery/utils/slice"
 	stringsutil "github.com/projectdiscovery/utils/strings"
+	"github.com/things-go/go-socks5"
 	"golang.org/x/net/proxy"
 )
 
@@ -180,15 +181,15 @@ func NewProxy(options *Options) (*Proxy, error) {
 
 	var socks5proxy *socks5.Server
 	if options.ListenAddrSocks5 != "" {
-		socks5Config := &socks5.Config{
-			Dial: proxy.httpTunnelDialer,
-		}
 		if options.Verbosity <= types.VerbositySilent {
-			socks5Config.Logger = log.New(io.Discard, "", log.Ltime|log.Lshortfile)
-		}
-		socks5proxy, err = socks5.New(socks5Config)
-		if err != nil {
-			return nil, err
+			socks5proxy = socks5.NewServer(
+				socks5.WithLogger(socks5.NewLogger(log.New(io.Discard, "", log.Ltime|log.Lshortfile))),
+				socks5.WithDial(proxy.httpTunnelDialer),
+			)
+		} else {
+			socks5proxy = socks5.NewServer(
+				socks5.WithDial(proxy.httpTunnelDialer),
+			)
 		}
 	}
 
@@ -199,6 +200,9 @@ func NewProxy(options *Options) (*Proxy, error) {
 
 // ModifyRequest
 func (p *Proxy) ModifyRequest(req *http.Request) error {
+	// // Set Content-Length to zero to allow automatic calculation
+	req.ContentLength = -1
+
 	ctx := martian.NewContext(req)
 	// disable upgrading http connections to https by default
 	ctx.Session().MarkInsecure()
@@ -239,10 +243,18 @@ func (p *Proxy) ModifyRequest(req *http.Request) error {
 	if len(p.options.RequestMatchReplaceDSL) != 0 {
 		_ = p.MatchReplaceRequest(req)
 	}
+	p.removeBrEncoding(req)
 	_ = p.logger.LogRequest(req, userData)
 	return nil
 }
 
+func (*Proxy) removeBrEncoding(req *http.Request) {
+	encodings := strings.Split(strings.ReplaceAll(req.Header.Get("Accept-Encoding"), " ", ""), ",")
+	encodings = sliceutil.PruneEqual(encodings, "br")
+	req.Header.Set("Accept-Encoding", strings.Join(encodings, ", "))
+
+}
+
 // ModifyResponse
 func (p *Proxy) ModifyResponse(resp *http.Response) error {
 	ctx := martian.NewContext(resp.Request)
@@ -332,7 +344,7 @@ func (p *Proxy) MatchReplaceRequest(req *http.Request) error {
 		return err
 	}
 	// closes old body to allow memory reuse
-	req.Body.Close()
+	_ = req.Body.Close()
 
 	// override original properties
 	req.Method = requestNew.Method
@@ -374,7 +386,7 @@ func (p *Proxy) MatchReplaceResponse(resp *http.Response) error {
 	}
 
 	// closes old body to allow memory reuse
-	resp.Body.Close()
+	_ = resp.Body.Close()
 	resp.Header = responseNew.Header
 	resp.Body, err = readerUtil.NewReusableReadCloser(responseNew.Body)
 	if err != nil {
@@ -520,7 +532,9 @@ func (p *Proxy) hijackNServe(req *http.Request, ctx *martian.Context) error {
 	if err != nil {
 		return err
 	}
-	defer conn.Close()
+	defer func() {
+		_ = conn.Close()
+	}()
 	rec := httptest.NewRecorder()
 	p.proxifyMux.ServeHTTP(rec, req)
 	resp := rec.Result()
@@ -528,7 +542,9 @@ func (p *Proxy) hijackNServe(req *http.Request, ctx *martian.Context) error {
 	if err := resp.Write(brw); err != nil {
 		gologger.Warning().Msgf("failed to write response: %v", err)
 	}
-	brw.Flush()
+	if err := brw.Flush(); err != nil {
+		gologger.Warning().Msgf("failed to flush buffer: %v", err)
+	}
 	return nil
 }
 
